@@ -6,9 +6,12 @@ def getAbi(connection, schema, token_address, chain_id):
     query = sql.SQL("SELECT abi FROM {}.evm_token \
            WHERE chain_id = %s AND token_address = %s").format(sql.Identifier(schema))
            
-    params = (schema, chain_id, token_address)
+    params = (chain_id, token_address)
     
-    result = herokuDbAccess.fetchDataInDatabase(query, params, connection)    
+    result = herokuDbAccess.fetchDataInDatabase(query, params, connection)
+    if len(result) == 0:
+           return None
+           
     return result[0][0]
 
 def updateAbi(connection, schema, abi, token_address, chain_id):
@@ -17,7 +20,7 @@ def updateAbi(connection, schema, abi, token_address, chain_id):
            SET abi=%s \
            WHERE chain_id = %s AND token_address = %s").format(sql.Identifier(schema))
            
-    params = (schema, abi, chain_id, token_address)
+    params = (abi, chain_id, token_address)
     
     herokuDbAccess.insertDataIntoDatabase(query, params, connection)    
     
\ No newline at end of file
